/****************************************************************************
    Qt-LCoV Library Editor for Qt-BSch3V
    Copyright (C) 2002-2005 H.Okada

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*****************************************************************************/

#include "prop_pin.h"

#include <qvariant.h>
#include <qpushbutton.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qspinbox.h>
#include <qcheckbox.h>
#include <q3buttongroup.h>
#include <qradiobutton.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <q3whatsthis.h>
#include <qimage.h>
#include <qpixmap.h>
//Added by qt3to4:
#include <QGridLayout>
#include <QHBoxLayout>
#include <QVBoxLayout>

#include "prop_pin.ui.h"
#include "pin_n.xpm"
#include "pin_nc.xpm"
#include "pin_c.xpm"
#include "pin_norm.xpm"
#include "pin_s.xpm"

/*
 *  Constructs a prop_pin as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */
prop_pin::prop_pin( QWidget* parent, const char* name, bool modal, Qt::WFlags fl )
    : QDialog( parent, name, modal, fl )
{
    if ( !name )
	setName( "prop_pin" );
    setMinimumSize( QSize( 370, 200 ) );
    setModal( TRUE );
    prop_pinLayout = new QGridLayout( this, 1, 1, 11, 6, "prop_pinLayout"); 

    layout4 = new QHBoxLayout( 0, 0, 6, "layout4"); 

    textLabel1 = new QLabel( this, "textLabel1" );
    textLabel1->setAlignment( int( Qt::AlignCenter ) );
    layout4->addWidget( textLabel1 );

    editName = new QLineEdit( this, "editName" );
    editName->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)0, 255, 0, editName->sizePolicy().hasHeightForWidth() ) );
    layout4->addWidget( editName );

    prop_pinLayout->addMultiCellLayout( layout4, 0, 0, 0, 1 );

    layout11 = new QHBoxLayout( 0, 0, 6, "layout11"); 

    layout5 = new QHBoxLayout( 0, 0, 6, "layout5"); 

    textLabel2 = new QLabel( this, "textLabel2" );
    textLabel2->setAlignment( int( Qt::AlignCenter ) );
    layout5->addWidget( textLabel2 );

    editNumber = new QLineEdit( this, "editNumber" );
    editNumber->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)7, (QSizePolicy::SizeType)0, 255, 0, editNumber->sizePolicy().hasHeightForWidth() ) );
    layout5->addWidget( editNumber );
    layout11->addLayout( layout5 );

    layout6 = new QHBoxLayout( 0, 0, 6, "layout6"); 

    textLabel2_2 = new QLabel( this, "textLabel2_2" );
    textLabel2_2->setAlignment( int( Qt::AlignCenter ) );
    layout6->addWidget( textLabel2_2 );

    spinBlock = new QSpinBox( this, "spinBlock" );
    layout6->addWidget( spinBlock );
    layout11->addLayout( layout6 );

    prop_pinLayout->addMultiCellLayout( layout11, 1, 1, 0, 1 );

    checkHide = new QCheckBox( this, "checkHide" );

    prop_pinLayout->addMultiCellWidget( checkHide, 2, 2, 0, 1 );

    layout15 = new QVBoxLayout( 0, 0, 6, "layout15"); 

    buttonOK = new QPushButton( this, "buttonOK" );
    buttonOK->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, buttonOK->sizePolicy().hasHeightForWidth() ) );
    layout15->addWidget( buttonOK );

    buttonCancel = new QPushButton( this, "buttonCancel" );
    buttonCancel->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, buttonCancel->sizePolicy().hasHeightForWidth() ) );
    layout15->addWidget( buttonCancel );

    prop_pinLayout->addLayout( layout15, 3, 1 );

    buttonGroup2 = new Q3ButtonGroup( this, "buttonGroup2" );
	buttonGroup2->setMinimumSize( QSize( 320, 100 ) );

    radioNeg = new QRadioButton( buttonGroup2, "radioNeg" );
    radioNeg->setGeometry( QRect( 119, 21, 90, 20 ) );
	radioNeg->setIcon(QIcon(QPixmap(pin_n)));
	radioNeg->setIconSize(QSize(60,20));
//    radioNeg->setPixmap( QPixmap::fromMimeSource( "pin_n.xpm" ) );
    radioNeg->setAutoRepeat( FALSE );

    radioNegCk = new QRadioButton( buttonGroup2, "radioNegCk" );
    radioNegCk->setGeometry( QRect( 119, 61, 90, 20 ) );
	radioNegCk->setIcon(QIcon(QPixmap(pin_nc)));
	radioNegCk->setIconSize(QSize(60,20));
//    radioNegCk->setPixmap( QPixmap::fromMimeSource( "pin_nc.xpm" ) );
    radioNegCk->setAutoRepeat( FALSE );

    radioCk = new QRadioButton( buttonGroup2, "radioCk" );
    radioCk->setGeometry( QRect( 19, 61, 90, 20 ) );
	radioCk->setIcon(QIcon(QPixmap(pin_c)));
	radioCk->setIconSize(QSize(60,20));
//    radioCk->setPixmap( QPixmap::fromMimeSource( "pin_c.xpm" ) );
    radioCk->setAutoRepeat( FALSE );

    radioNorm = new QRadioButton( buttonGroup2, "radioNorm" );
    radioNorm->setGeometry( QRect( 18, 22, 90, 20 ) );
	radioNorm->setIcon(QIcon(QPixmap(pin_norm)));
	radioNorm->setIconSize(QSize(60,20));
//    radioNorm->setPixmap( QPixmap::fromMimeSource( "pin_norm.xpm" ) );
    radioNorm->setAutoRepeat( FALSE );

    radioS = new QRadioButton( buttonGroup2, "radioS" );
    radioS->setGeometry( QRect( 219, 21, 90, 20 ) );
   	radioS->setIcon(QIcon(QPixmap(pin_s)));
	radioS->setIconSize(QSize(60,20));
//    radioS->setPixmap( QPixmap::fromMimeSource( "pin_s.xpm" ) );
    radioS->setAutoRepeat( FALSE );

    prop_pinLayout->addWidget( buttonGroup2, 3, 0 );
    languageChange();
    resize( QSize(435, 200).expandedTo(minimumSizeHint()) );
    //clearWState( WState_Polished );

    // signals and slots connections
    connect( buttonOK, SIGNAL( clicked() ), this, SLOT( accept() ) );
    connect( buttonCancel, SIGNAL( clicked() ), this, SLOT( close() ) );
    connect( spinBlock, SIGNAL( valueChanged(int) ), this, SLOT( changeBlock(int) ) );

    // tab order
    setTabOrder( editName, editNumber );
    setTabOrder( editNumber, spinBlock );
    setTabOrder( spinBlock, radioNorm );
    setTabOrder( radioNorm, radioNeg );
    setTabOrder( radioNeg, radioS );
    setTabOrder( radioS, radioCk );
    setTabOrder( radioCk, radioNegCk );
    setTabOrder( radioNegCk, buttonOK );
    setTabOrder( buttonOK, buttonCancel );
    setTabOrder( buttonCancel, checkHide );
}

/*
 *  Destroys the object and frees any allocated resources
 */
prop_pin::~prop_pin()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void prop_pin::languageChange()
{
    setCaption( tr( "Pin Property" ) );
    textLabel1->setText( tr( "Name" ) );
    textLabel2->setText( tr( "Number" ) );
    textLabel2_2->setText( tr( "Block" ) );
    checkHide->setText( tr( "Hide Number" ) );
    buttonOK->setText( tr( "OK" ) );
    buttonCancel->setText( tr( "Cancel" ) );
    buttonGroup2->setTitle( tr( "Pin Type" ) );
    radioNeg->setText( QString::null );
    radioNegCk->setText( QString::null );
    radioCk->setText( QString::null );
    radioNorm->setText( QString::null );
    radioS->setText( QString::null );
}

